@@ -41,7 +41,7 @@
 #  if defined (HAVE_STDLIB_H)
 #    include <stdlib.h>
 #  endif
-#  if defined (HAVE_STRING_H)
+#  if defined (STDC_HEADERS) /* (HAVE_STRING_H) */
 #    include <string.h>
 #  else /* !HAVE_STRING_H */
 #    include <strings.h>
@@ -254,7 +254,7 @@ glob_vector (pat, dir)
   register char *nextname, *npat;
   unsigned int count;
   int lose, skip;
-  register char **name_vector;
+  register char **name_vector=0;
   register unsigned int i;
   int flags;		/* Flags passed to fnmatch (). */
 
