@@ -1,4 +1,4 @@
-/* $Id: bookmark.c,v 1.12 2001/05/12 18:44:37 mhe Exp $
+/* $Id: bookmark.c,v 1.14 2001/07/09 18:27:42 mhe Exp $
  *
  * bookmark.c -- create bookmark(s)
  *
@@ -98,6 +98,8 @@ static void bookmark_save_one(FILE *fp, url_t *url)
 	}
 	if(url->pasvmode != -1)
 		fprintf(fp, " passive %s", url->pasvmode ? "true" : "false");
+	if(url->sftp_server)
+		fprintf(fp, " sftp %s", url->sftp_server);
 	fprintf(fp, "\n\n");
 }
 
@@ -292,6 +294,8 @@ static bool should_update_bookmark(url_t *url)
 		return true;
 	if(xstrcmp(url->protocol, ftp->url->protocol) != 0)
 		return true;
+	if(xstrcmp(url->sftp_server, ftp->url->sftp_server) != 0)
+		return true;
 	return false;
 }
 
@@ -487,7 +491,8 @@ void cmd_bookmark(int argc, char **argv)
 			url_t *u = (url_t *)li->data;
 			/* note: all info not printed */
 			printf("%-20s", u->alias ? u->alias : u->hostname);
-			printf("%s@%s", u->username, u->hostname);
+			printf("%s://%s@%s", u->protocol ? u->protocol : "ftp",
+				   u->username, u->hostname);
 			if(u->directory)
 				printf("/%s", shortpath(u->directory, 30, 0));
 			putchar('\n');
