@@ -1,4 +1,4 @@
-/* $Id: ftp.c,v 1.18 2001/05/12 18:44:04 mhe Exp $
+/* $Id: ftp.c,v 1.27 2001/07/09 18:47:54 mhe Exp $
  *
  * ftp.c -- low(er) level FTP stuff
  *
@@ -19,6 +19,7 @@
 #include "gvars.h"
 #include "ssh_cmd.h"
 #include "sftp-common.h"
+#include "args.h"
 
 /* in cmd.c */
 void exit_yafc(void);
@@ -48,13 +49,14 @@ Ftp *ftp_create(void)
 	ftp->reply_timeout = 30;
 	ftp->open_timeout = 30;
 	ftp->taglist = list_new((listfunc)rfile_destroy);
-#if defined(KRB4) || defined(KRB5)
+#ifdef SECFTP
 	ftp->app_data = 0;
 /*	ftp->in_buffer = 0;*/
 /*	ftp->out_buffer = 0;*/
 #endif
 	ftp->LIST_type = ltUnknown;
 	ftp->ssh_id = 1;
+	ftp->ssh_args = args_create();
 
 	return ftp;
 }
@@ -127,8 +129,10 @@ void ftp_destroy(Ftp *ftp)
 	xfree(ftp->curdir);
 	xfree(ftp->prevdir);
 	list_free(ftp->taglist);
+	args_destroy(ftp->ssh_args);
+	ftp->ssh_args = 0;
 
-#if defined(KRB4) || defined(KRB5)
+#ifdef SECFTP
 	sec_end();
 #endif
 
@@ -183,8 +187,7 @@ void ftp_reset_vars(void)
 		close(ftp->ssh_out);
 		ftp->ssh_id = 0;
 	}
-	xfree(ftp->ssh_args);
-	ftp->ssh_args = 0;
+	args_clear(ftp->ssh_args);
 
 	url_destroy(ftp->url);
 	ftp->url = 0;
@@ -198,6 +201,7 @@ void ftp_reset_vars(void)
 	ftp->has_stou_command = true;
 	ftp->has_site_chmod_command = true;
 	ftp->has_site_idle_command = true;
+	ftp->has_mlsd_command = true;
 
 	list_free(ftp->dirs_to_flush);
 	ftp->dirs_to_flush = list_new((listfunc)xfree);
@@ -216,7 +220,7 @@ void ftp_reset_vars(void)
 	xfree(ftp->last_mkpath);
 	ftp->last_mkpath = 0;
 
-#if defined(KRB4) || defined(KRB5)
+#ifdef SECFTP
 	sec_end();
 	ftp->request_data_prot = 0;
 	ftp->buffer_size = 0;
@@ -265,6 +269,8 @@ int ftp_open_url(url_t *urlp, bool reset_vars)
 
 	if(reset_vars)
 		ftp_reset_vars();
+	/* don't assume server is in ascii mode initially even if RFC says so */
+	ftp->prev_type = '?';
 
 #ifdef HAVE_POSIX_SIGSETJMP
 	if(sigsetjmp(open_timeout_jmp, 1))
@@ -466,7 +472,7 @@ static int ftp_gets(void)
 
 	ftp->reply[i] = '\0';
 	ftp->fullcode = atoi(ftp->reply);
-#if defined(KRB4) || defined(KRB5)
+#ifdef SECFTP
 	{
 		int r = 0;
 		switch(ftp->fullcode) { /* handle protected responses 6xx */
@@ -777,7 +783,7 @@ static int get_password(url_t *url, const char *anonpass, bool isproxy)
 	return 0;
 }
 
-#if defined(KRB4) || defined(KRB5)
+#ifdef SECFTP
 
 static const char *secext_name(const char *mech)
 {
@@ -785,9 +791,15 @@ static const char *secext_name(const char *mech)
 		const char *short_name;
 		const char *real_name;
 	} names[] = {
+#ifdef KRB4
 		{"krb4", "KERBEROS_V4"},
+#endif
+#ifdef KRB5
 		{"krb5", "GSSAPI"},
-/*		{"ssl", "SSL"},*/
+#endif
+#ifdef SSL
+		{"ssl", "SSL"},
+#endif
 		{"none", "none"},
 		{0, 0}
 	};
@@ -810,11 +822,15 @@ static bool mech_unsupported(const char *mech)
 #ifndef KRB5
 	if(strcasecmp(mech, "GSSAPI") == 0)
 		return true;
+#endif
+#ifndef USE_SSL
+	if(strcasecmp(mech, "SSL") == 0)
+		return true;
 #endif
 	return false;
 }
 
-#endif /* KRB4 or KRB5 */
+#endif /* SECFTP */
 
 int ftp_login(const char *guessed_username, const char *anonpass)
 {
@@ -848,7 +864,7 @@ int ftp_login(const char *guessed_username, const char *anonpass)
 			return r;
 	}
 
-#if defined(KRB4) || defined(KRB5)
+#ifdef SECFTP
 	ftp->sec_complete = false;
 	ftp->data_prot = prot_clear;
 
@@ -1000,7 +1016,7 @@ int ftp_login(const char *guessed_username, const char *anonpass)
 	}
 	if(ftp->code == ctComplete) {
 		ftp->loggedin = true;
-#if defined(KRB4) || defined(KRB5)
+#ifdef SECFTP
 		/* we are logged in, now set the requested data protection level
 		 * requested from the autologin information in the config file,
 		 * if any, else uses default protection level 'clear', ie
@@ -1017,6 +1033,7 @@ int ftp_login(const char *guessed_username, const char *anonpass)
 		ftp->prevdir = xstrdup(ftp->homedir);
 		if(ftp->url->directory)
 			ftp_chdir(ftp->url->directory);
+		ftp_get_feat();
 		return 0;
 	}
 	if(ftp->code == ctTransient)
@@ -1083,10 +1100,20 @@ int ftp_chdir(const char *path)
 	ftp_set_tmp_verbosity(vbCommand);
 	ftp_cmd("CWD %s", path);
 	if(ftp->code == ctComplete) {
+		/* Now, try to be smart ;-)
+		 * Many ftp servers include the current directory in the CWD reply
+		 * try to parse it, so we don't need to issue a PWD command
+		 */
+
 		if(strncasecmp(ftp->reply, "250 Changed to ", 15) == 0) {
 			/* this is what Troll-ftpd replies: 250 Changed to /foo/bar */
 			ftp_update_curdir_x(ftp->reply+15);
 			ftp_trace("Parsed cwd '%s' from reply\n", ftp->curdir);
+		} else if(strncasecmp(ftp->reply,
+							  "250 OK. Current directory is ", 29) == 0) {
+			/* PureFTPd responds: "250 OK. Current directory is /foo/bar */
+			ftp_update_curdir_x(ftp->reply+29);
+			ftp_trace("Parsed cwd '%s' from reply\n", ftp->curdir);
 		} else if(strstr(ftp->reply, " is current directory") != 0) {
 			/* WarFTPD answers: 250 "/foo/bar/" is current directory */
 			char *edq;
@@ -1313,18 +1340,35 @@ rdirectory *ftp_read_directory(const char *path)
 
 	fchmod(fileno(fp), S_IRUSR | S_IWUSR);
 
-	if(!is_curdir) {
-		ftp_cmd("CWD %s", dir);
-		if(ftp->code != ctComplete)
-			goto failed;
+	if(ftp->has_mlsd_command) {
+		char *asdf;
+		asprintf(&asdf, "%s/", dir);
+		/* Hack to get around issue in PureFTPd (up to version 0.98.2):
+		 * doing a 'MLSD link-to-dir' on PureFTPd closes the control
+		 * connection, however, 'MLSD link-to-dir/' works fine.
+		 */
+		_failed = (ftp_list("MLSD", asdf, fp) != 0);
+		xfree(asdf);
+		if(_failed && ftp->code == ctError)
+			ftp->has_mlsd_command = false;
 	}
+	if(!ftp->has_mlsd_command) {
 
-	_failed = (ftp_list("LIST", 0, fp) != 0);
+		/* we do a "CWD" before the listing, because:
+		 *  we want a listing of the directory contents, not the
+		 *  directory itself, and some servers misunderstand this
+		 *  If the target is a link to a directory, we have to do this
+		 */
+		if(!is_curdir) {
+			ftp_cmd("CWD %s", dir);
+			if(ftp->code != ctComplete)
+				goto failed;
+		}
 
-	if(!is_curdir) {
-		ftp_cmd("CWD %s", ftp->curdir);
-/*		if(ftp->code != ctComplete)*/
-/*			goto failed;*/
+		_failed = (ftp_list("LIST", 0, fp) != 0);
+
+		if(!is_curdir)
+			ftp_cmd("CWD %s", ftp->curdir);
 	}
 
 	if(_failed)
@@ -1706,9 +1750,60 @@ int ftp_maybe_isdir(rfile *fp)
 
 void ftp_pwd(void)
 {
-	if(ftp->ssh_pid)
-		return ssh_pwd();
+	if(ftp->ssh_pid) {
+		ssh_pwd();
+		return;
+	}
 
 	ftp_set_tmp_verbosity(vbCommand);
 	ftp_cmd("PWD");
 }
+
+
+char *perm2string(int perm)
+{
+	char *attr = (char *)xmalloc(11);
+
+	strcpy(attr, "----------");
+
+	if(S_ISDIR(perm))
+		attr[0] = 'd';
+	else if(S_ISLNK(perm))
+		attr[0] = 'l';
+	else if(S_ISCHR(perm))
+		attr[0] = 'c';
+	else if(S_ISBLK(perm))
+		attr[0] = 'b';
+	else if(S_ISFIFO(perm))
+		attr[0] = 'p';
+	else if(S_ISSOCK(perm))
+		attr[0] = 's';
+
+	if(test(perm, S_IRUSR)) attr[1] = 'r';
+	if(test(perm, S_IWUSR)) attr[2] = 'w';
+	if(test(perm, S_IXUSR)) {
+		if(test(perm, S_ISUID)) attr[3] = 's';
+		else attr[3] = 'x';
+	} else if(test(perm, S_ISUID)) attr[3] = 'S';
+
+	if(test(perm, S_IRGRP)) attr[4] = 'r';
+	if(test(perm, S_IWGRP)) attr[5] = 'w';
+	if(test(perm, S_IXGRP)) {
+		if(test(perm, S_ISGID)) attr[6] = 's';
+		else attr[6] = 'x';
+	} else if(test(perm, S_ISGID)) attr[6] = 'S';
+
+	if(test(perm, S_IROTH)) attr[7] = 'r';
+	if(test(perm, S_IWOTH)) attr[8] = 'w';
+	if(test(perm, S_IXOTH)) {
+		if(test(perm, S_ISVTX)) attr[9] = 't';
+		else attr[9] = 'x';
+	} else if(test(perm, S_ISVTX)) attr[9] = 'T';
+
+	return attr;
+}
+
+void ftp_get_feat(void)
+{
+/*	ftp_cmd("FEAT");*/
+}
