@@ -1,4 +1,4 @@
-/* $Id: list.c,v 1.7 2001/05/12 18:44:37 mhe Exp $
+/* $Id: list.c,v 1.10 2001/05/28 16:04:07 mhe Exp $
  *
  * list.c -- the remote cached 'ls' command
  *
@@ -279,13 +279,18 @@ static void ls_opl(list *gl, unsigned opt, bool doclr)
 	}
 }
 
+static int ls_sort_name(rfile *a, rfile *b)
+{
+	return strcmp(a->path, b->path);
+}
+
 static int ls_sort_dirs(rfile *a, rfile *b)
 {
 	if(risdir(a) && !risdir(b))
 		return -1;
 	if(!risdir(a) && risdir(b))
 		return 1;
-	return 0;
+	return ls_sort_name(a, b);
 }
 
 static int ls_sort_size(rfile *a, rfile *b)
@@ -326,11 +331,6 @@ static int ls_sort_mtime(rfile *a, rfile *b)
 	return 0;
 }
 
-static int ls_sort_name(rfile *a, rfile *b)
-{
-	return strcmp(a->path, b->path);
-}
-
 static void ls_all(list *gl, unsigned opt, bool doclr)
 {
 	if(list_numitem(gl) == 0)
@@ -468,7 +468,7 @@ void cmd_ls(int argc, char **argv)
 			break;
 		  case 'S':
 			opt |= LS_SORT_SIZE;
-			opt &= ~(LS_SORT_EXT | LS_SORT_DIRS_FIRST | LS_SORT_MTIME);
+			opt &= ~(LS_SORT_EXT | LS_SORT_DIRS_FIRST | LS_SORT_MTIME | LS_SORT_NAME);
 			break;
 		  case 'U':
 			opt &= ~(LS_SORT_NAME | LS_SORT_SIZE | LS_SORT_EXT
@@ -485,11 +485,11 @@ void cmd_ls(int argc, char **argv)
 			break;
 		  case 't':
 			opt |= LS_SORT_MTIME;
-			opt &= ~(LS_SORT_SIZE | LS_SORT_EXT | LS_SORT_DIRS_FIRST);
+			opt &= ~(LS_SORT_SIZE | LS_SORT_EXT | LS_SORT_DIRS_FIRST | LS_SORT_NAME);
 			break;
 		  case 'X':
 			opt |= LS_SORT_EXT;
-			opt &= ~(LS_SORT_SIZE | LS_SORT_DIRS_FIRST | LS_SORT_MTIME);
+			opt &= ~(LS_SORT_SIZE | LS_SORT_DIRS_FIRST | LS_SORT_MTIME | LS_SORT_NAME);
 			break;
 		  case 'c':
 			if(optarg == 0 || strcmp(optarg, "always") == 0) {
@@ -505,7 +505,7 @@ void cmd_ls(int argc, char **argv)
 			break;
 		case '2': /* --dirs-first */
 			opt |= LS_SORT_DIRS_FIRST;
-			opt &= ~(LS_SORT_SIZE | LS_SORT_EXT | LS_SORT_MTIME);
+			opt &= ~(LS_SORT_SIZE | LS_SORT_EXT | LS_SORT_MTIME | LS_SORT_NAME);
 			break;
 		case '3': /* --help */
 			print_ls_syntax();
@@ -546,7 +546,7 @@ void cmd_ls(int argc, char **argv)
 					rfile *rf;
 					char *q = xstrdup(e);
 					unquote(q);
-					rdir = ftp_get_directory(q);
+					rdir = ftp_cache_get_directory(q);
 					if(rdir)
 						isdir = true;
 					else {
