@@ -1,4 +1,4 @@
-/* $Id: main.c,v 1.15 2001/05/13 14:36:26 mhe Exp $
+/* $Id: main.c,v 1.18 2001/05/28 10:13:41 mhe Exp $
  *
  * main.c -- parses command line options and starts Yafc
  *
@@ -38,7 +38,8 @@ void print_syntax_and_exit(char *argv0)
 {
 	printf(COPYLINE "\n");
 	printf(_("This is yet another FTP client.  Usage:\n"
-			 "  %s [options] [[ftp://][user[:password]@]hostname[:port][/directory] ...]\n"
+			 " %s [options] [[proto://][user[:password]@]hostname[:port][/directory] ...]\n"
+			 " proto can be either 'ftp' or 'ssh'\n"
 			 "Options:\n"
 			 "  -a, --anon        (*) anonymous login\n"
 			 "  -d, --debug           print all commands sent to/from server\n"
@@ -153,11 +154,19 @@ void init_yafc(void)
 #ifdef KRB4
 # ifdef KRB5
 	listify_string("krb4:krb5:none", gvDefaultMechanism);
+# elif defined(USE_SSL)
+	listify_string("krb4:krb5:ssl:none", gvDefaultMechanism);
 # else
 	listify_string("krb4:none", gvDefaultMechanism);
 # endif
 #elif defined(KRB5)
+# ifdef USE_SSL
+	listify_string("krb5:ssl:none", gvDefaultMechanism);
+# else
 	listify_string("krb5:none", gvDefaultMechanism);
+# endif
+#elif defined(USE_SSL)
+	listify_string("ssl", gvDefaultMechanism);
 #else
 	listify_string("none", gvDefaultMechanism);
 #endif
@@ -188,7 +197,7 @@ void init_yafc(void)
 	gvTransferString = xstrdup("%5p%% [%25v] %s/%S ETA %e %B");
 /*	gvTransferEndString = xstrdup("%-40R      %s in %t @ %b\n");*/
 
-	gvTransferXtermString = xstrdup("\e]0;yafc - (%p%%) %r\x07");
+	gvTransferXtermString = xstrdup("\x1B]0;yafc - (%p%%) %r\x07");
 
 	input_init();
 }
@@ -425,7 +434,7 @@ int main(int argc, char **argv, char **envp)
 			open_opt |= OP_NOAUTO;
 
 		for(i=optind; i<argc; i++) {
-			yafc_open(argv[i], open_opt, mech);
+			yafc_open(argv[i], open_opt, mech, 0);
 #ifdef HAVE_LIBREADLINE /* add appropriate 'open' command to history */
 			asprintf(&s, "open %s%s",
 					 argv[i], test(open_opt, OP_ANON) ? " --anon" : "");
