@@ -1,4 +1,4 @@
-/* $Id: syshdr.h,v 1.7 2001/05/13 11:49:43 mhe Exp $
+/* $Id: syshdr.h,v 1.11 2001/05/28 09:51:57 mhe Exp $
  *
  * syshdr.h -- includes global header files etc.
  *
@@ -22,6 +22,58 @@
 # include <sys/types.h>
 #endif
 
+/* data type checks stolen from openssh-2.9p1
+ */
+#ifdef HAVE_SYS_BITYPES_H
+# include <sys/bitypes.h> /* For u_intXX_t */
+#endif
+/* If sys/types.h does not supply u_intXX_t, supply them ourselves */
+#ifndef HAVE_U_INTXX_T
+# ifdef HAVE_UINTXX_T
+typedef uint8_t u_int8_t;
+typedef uint16_t u_int16_t;
+typedef uint32_t u_int32_t;
+# define HAVE_U_INTXX_T 1
+# else
+#  if (SIZEOF_CHAR == 1)
+typedef unsigned char u_int8_t;
+#  else
+#   error "8 bit int type not found."
+#  endif
+#  if (SIZEOF_SHORT_INT == 2)
+typedef unsigned short int u_int16_t;
+#  else
+#   ifdef _CRAY
+typedef unsigned long  u_int16_t;
+#   else
+#    error "16 bit int type not found."
+#   endif
+#  endif
+#  if (SIZEOF_INT == 4)
+typedef unsigned int u_int32_t;
+#  else
+#   ifdef _CRAY
+typedef unsigned long  u_int32_t;
+#   else
+#    error "32 bit int type not found."
+#   endif
+#  endif
+# endif
+#endif
+/* 64-bit types */
+#ifndef HAVE_U_INT64_T
+# ifdef HAVE_UINT64_T
+typedef uint64_t u_int64_t;
+#  define HAVE_U_INT64_T 1
+# elif (SIZEOF_LONG_INT == 8)
+typedef unsigned long int u_int64_t;
+#  define HAVE_U_INT64_T 1
+# elif (SIZEOF_LONG_LONG_INT == 8)
+typedef unsigned long long int u_int64_t;
+#  define HAVE_U_INT64_T 1
+# endif
+#endif
+
 #include <stdio.h>
 #include <ctype.h>
 #include <signal.h>
@@ -49,7 +101,7 @@ int asprintf(char **strp, const char *format, ...);
 # include "setproctitle.h"
 #endif
 
-#if STDC_HEADERS
+#ifdef STDC_HEADERS
 # include <string.h>
 #else
 # ifndef HAVE_STRCHR
@@ -164,7 +216,8 @@ extern int rl_filename_completion_desired;
 
 #define min(a, b) ((a) < (b) ? (a) : (b))
 
-#if defined(KRB4) || defined(KRB5)
+#if defined(KRB4) || defined(KRB5) || defined(USE_SSL)
+# define SECFTP
 # ifdef HAVE_DES_H
 #  include <des.h>
 # endif
